@@ -31,7 +31,7 @@ use strict;
 # Build updates this
 #
 use constant {
-    VERSION => '5.2.0.5'
+    VERSION => '4.6.0'
 };
 
 my %params;
@@ -52,9 +52,6 @@ for ( @ARGV ) {
     $params{$pn} = $pv;
 }
 
-use File::Basename;
-chdir dirname($0);
-
 my $vendor = $params{HOST};
 my $rcfile;
 my $rcfilename;
@@ -67,56 +64,27 @@ unless ( defined $vendor ) {
 
 	$id =~ s/ID=//;
 	
-	if ( $id eq 'fedora' || $id eq 'rhel' ) {
+	if ( $id eq 'fedora' ) {
 	    $vendor = 'redhat';
 	} elsif ( $id eq 'opensuse' ) {
 	    $vendor = 'suse';
-	} elsif ( $id eq 'ubuntu' || $id eq 'debian' ) {
-	    my $init = `ls -l /sbin/init`;
-	    $vendor = $init =~ /systemd/ ? 'debian.systemd' : 'debian.sysvinit';
+	} elsif ( $id eq 'ubuntu' ) {
+	    $vendor = 'debian';
 	} else {
 	    $vendor = $id;
 	}
     }
 
     $params{HOST} = $vendor;
-    $params{HOST} =~ s/\..*//;
 }
 
 if ( defined $vendor ) {
-    if ( $vendor eq 'debian' && -f '/etc/debian_version' ) {
-	if ( -l '/sbin/init' ) {
-	    if ( readlink('/sbin/init') =~ /systemd/ ) {
-		$rcfilename = 'shorewallrc.debian.systemd';
-	    } else {
-		$rcfilename = 'shorewallrc.debian.sysvinit';
-	    }
-	} else {
-	    $rcfilename = 'shorewallrc.debian.sysvinit';
-	}
-    } else {
-	$rcfilename = $vendor eq 'linux' ? 'shorewallrc.default' : 'shorewallrc.' . $vendor;
-    }
-
-    unless ( -f $rcfilename ) {
-	die qq("ERROR: $vendor" is not a recognized host type);
-    } elsif ( $vendor eq 'default' ) {
-	$params{HOST} = $vendor = 'linux';
-    } elsif ( $vendor =~ /^debian\./ ) {
-	$params{HOST} = $vendor = 'debian';
-    }
+    $rcfilename = $vendor eq 'linux' ? 'shorewallrc.default' : 'shorewallrc.' . $vendor;
+    die qq("ERROR: $vendor" is not a recognized host type) unless -f $rcfilename;
 } else {
     if ( -f '/etc/debian_version' ) {
 	$vendor = 'debian';
-	if ( -l '/sbin/init' ) {
-	    if ( readlink( '/sbin/init' ) =~ /systemd/ ) {
-		$rcfilename = 'shorewallrc.debian.systemd';
-	    } else {
-		$rcfilename = 'shorewallrc.debian.sysvinit';
-	    }
-	} else {
-	    $rcfilename = 'shorewallrc.debian.sysvinit';
-	}
+	$rcfilename = 'shorewallrc.debian';
     } elsif ( -f '/etc/redhat-release' ){
 	$vendor = 'redhat';
 	$rcfilename = 'shorewallrc.redhat';
@@ -132,7 +100,7 @@ if ( defined $vendor ) {
     } elsif ( `uname` =~ '^Darwin' ) {
 	$vendor = 'apple';
 	$rcfilename = 'shorewallrc.apple';
-    } elsif ( `uname` =~ /^Cygwin/i ) {
+    } elsif ( `uname` =~ '^Cygwin' ) {
 	$vendor = 'cygwin';
 	$rcfilename = 'shorewallrc.cygwin';
     } else {
@@ -149,7 +117,7 @@ my @abbr = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec );
 if ( $vendor eq 'linux' ) {
     printf "INFO: Creating a generic Linux installation - %s %2d %04d %02d:%02d:%02d\n\n", $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];;
 } else {
-    printf "INFO: Creating a %s-specific installation - %s %2d %04d %02d:%02d:%02d\n\n", $params{HOST}, $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];;
+    printf "INFO: Creating a %s-specific installation - %s %2d %04d %02d:%02d:%02d\n\n", $vendor, $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];;
 }
 
 open $rcfile, '<', $rcfilename or die "Unable to open $rcfilename for input: $!";
@@ -173,13 +141,7 @@ my $outfile;
 
 open $outfile, '>', 'shorewallrc' or die "Can't open 'shorewallrc' for output: $!";
 
-if ( $ENV{SOURCE_DATE_EPOCH} ) {
-    printf $outfile "#\n# Created by Shorewall Core version %s configure.pl - %s\n", VERSION, `date  --utc --date=\"\@$ENV{SOURCE_DATE_EPOCH}\"`;
-} else {
-    printf $outfile "#\n# Created by Shorewall Core version %s configure.pl - %s %2d %04d %02d:%02d:%02d\n", VERSION, $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];
-}
-
-print $outfile "# rc file: $rcfilename\n#\n";
+printf $outfile "#\n# Created by Shorewall Core version %s configure.pl - %s %2d %04d %02d:%02d:%02d\n#\n", VERSION, $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];
 
 print  $outfile "# Input: @ARGV\n#\n" if @ARGV;
 
@@ -192,8 +154,6 @@ if ( $options{VARLIB} ) {
     $options{VARDIR} = '${VARLIB}/${PRODUCT}';
 }
 
-$options{SERVICEDIR}=$options{SYSTEMD} unless $options{SERVICEDIR};
-
 for ( qw/ HOST
 	  PREFIX
 	  SHAREDIR
@@ -207,15 +167,14 @@ for ( qw/ HOST
 	  INITFILE
 	  AUXINITSOURCE
 	  AUXINITFILE
-	  SERVICEDIR
-	  SERVICEFILE
+	  SYSTEMD
+          SERVICEFILE
 	  SYSCONFFILE
 	  SYSCONFDIR
 	  SPARSE
 	  ANNOTATED
 	  VARLIB
-	  VARDIR
-          DEFAULT_PAGER / ) {
+	  VARDIR / ) {
 
     my $val = $options{$_} || '';
 
